==> typescript-nestjs-swagger-plugin-1.0.0.tgz: package/README.md <==
# typescript-nestjs-swagger-plugin

[![version](https://img.shields.io/npm/v/typescript-nestjs-swagger-plugin.svg?style=flat-square)](https://www.npmjs.com/package/typescript-nestjs-swagger-plugin)
[![downloads](https://img.shields.io/npm/dm/typescript-nestjs-swagger-plugin.svg?style=flat-square)](https://www.npmjs.com/package/typescript-nestjs-swagger-plugin)
[![license](https://img.shields.io/npm/l/typescript-nestjs-swagger-plugin.svg?style=flat-square)](https://www.npmjs.com/package/typescript-nestjs-swagger-plugin)
[![dependencies](https://img.shields.io/david/Val-istar-Guo/typescript-nestjs-swagger-plugin.svg?style=flat-square)](https://www.npmjs.com/package/typescript-nestjs-swagger-plugin)
[![coveralls](https://img.shields.io/coveralls/github/Val-istar-Guo/typescript-nestjs-swagger-plugin.svg?style=flat-square)](https://coveralls.io/github/Val-istar-Guo/typescript-nestjs-swagger-plugin)



<!-- description -->
[@nestjs/swagger ttypescript plugin](https://docs.nestjs.com/openapi/cli-plugin) reduce the amount of boilerplate code required.
<!-- description -->

## Usage

<!-- usage -->
Add this plugin to `tsconfig.json`.

```javascript
{
  "compilerOptions": {
    // ...other options
    "plugins": [
      { "transform": "./build/typescript-nestjs-swagger.ts" },
    ]
  },
}
```
<!-- usage -->

<!-- addition --><!-- addition -->

## Sponsor

Support code development on patron.

[![patron](https://c5.patreon.com/external/logo/become_a_patron_button@2x.png)](https://www.patreon.com/bePatron?u=22478507)

## Contributing & Development

If there is any doubt, it is very welcome to discuss the issue together.
Please read [Contributor Covenant Code of Conduct](.github/CODE_OF_CONDUCT.md) and [CONTRIBUTING](.github/CONTRIBUTING.md).

==> typescript-nestjs-swagger-plugin-1.1.1.tgz: package/README.md <==
# typescript-nestjs-swagger-plugin

[![version](https://img.shields.io/npm/v/typescript-nestjs-swagger-plugin.svg?style=flat-square)](https://www.npmjs.com/package/typescript-nestjs-swagger-plugin)
[![downloads](https://img.shields.io/npm/dm/typescript-nestjs-swagger-plugin.svg?style=flat-square)](https://www.npmjs.com/package/typescript-nestjs-swagger-plugin)
[![license](https://img.shields.io/npm/l/typescript-nestjs-swagger-plugin.svg?style=flat-square)](https://www.npmjs.com/package/typescript-nestjs-swagger-plugin)
[![dependencies](https://img.shields.io/david/Val-istar-Guo/typescript-nestjs-swagger-plugin.svg?style=flat-square)](https://www.npmjs.com/package/typescript-nestjs-swagger-plugin)
[![coveralls](https://img.shields.io/coveralls/github/Val-istar-Guo/typescript-nestjs-swagger-plugin.svg?style=flat-square)](https://coveralls.io/github/Val-istar-Guo/typescript-nestjs-swagger-plugin)



<!-- description -->
[@nestjs/swagger ttypescript plugin](https://docs.nestjs.com/openapi/cli-plugin) reduce the amount of boilerplate code required.
<!-- description -->

## Usage

<!-- usage -->
Add this plugin to `tsconfig.json`.

```javascript
{
  "compilerOptions": {
    // ...other options
    "plugins": [
      { "transform": "./build/typescript-nestjs-swagger.ts", "introspectComments": true },
    ]
  },
}
```

For all options supported, please see: [@nestjs/swagger](https://docs.nestjs.com/openapi/cli-plugin#using-the-cli-plugin)
<!-- usage -->

<!-- addition --><!-- addition -->

## Sponsor

Support code development on patron.

[![patron](https://c5.patreon.com/external/logo/become_a_patron_button@2x.png)](https://www.patreon.com/bePatron?u=22478507)

## Contributing & Development

If there is any doubt, it is very welcome to discuss the issue together.
Please read [Contributor Covenant Code of Conduct](.github/CODE_OF_CONDUCT.md) and [CONTRIBUTING](.github/CONTRIBUTING.md).
